==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/securityhub/HubReference.java <==
package software.amazon.awscdk.interfaces.securityhub;

/**
 * A reference to a Hub resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.securityhub.*;
 * HubReference hubReference = HubReference.builder()
 *         .hubARN("hubARN")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.949Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_securityhub.HubReference")
@software.amazon.jsii.Jsii.Proxy(HubReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface HubReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the Hub resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getHubARN();

    /**
     * @return a {@link Builder} of {@link HubReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HubReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<HubReference> {
        java.lang.String hubArn;

        /**
         * Sets the value of {@link HubReference#getHubArn}
         * @param hubArn The ARN of the Hub resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hubArn(java.lang.String hubArn) {
            this.hubArn = hubArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HubReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public HubReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link HubReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HubReference {
        private final java.lang.String hubArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.hubArn = software.amazon.jsii.Kernel.get(this, "hubARN", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.hubArn = java.util.Objects.requireNonNull(builder.hubArn, "hubArn is required");
        }

        @Override
        public final java.lang.String getHubARN() {
            return this.hubArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("hubARN", om.valueToTree(this.getHubARN()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_securityhub.HubReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HubReference.Jsii$Proxy that = (HubReference.Jsii$Proxy) o;

            return this.hubArn.equals(that.hubArn);
        }

        @Override
        public final int hashCode() {
            int result = this.hubArn.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/securityhub/HubReference.java <==
package software.amazon.awscdk.interfaces.securityhub;

/**
 * A reference to a Hub resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.securityhub.*;
 * HubReference hubReference = HubReference.builder()
 *         .hubArn("hubArn")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.165Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_securityhub.HubReference")
@software.amazon.jsii.Jsii.Proxy(HubReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface HubReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the Hub resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getHubArn();

    /**
     * @return a {@link Builder} of {@link HubReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HubReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<HubReference> {
        java.lang.String hubArn;

        /**
         * Sets the value of {@link HubReference#getHubArn}
         * @param hubArn The ARN of the Hub resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hubArn(java.lang.String hubArn) {
            this.hubArn = hubArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HubReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public HubReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link HubReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HubReference {
        private final java.lang.String hubArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.hubArn = software.amazon.jsii.Kernel.get(this, "hubArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.hubArn = java.util.Objects.requireNonNull(builder.hubArn, "hubArn is required");
        }

        @Override
        public final java.lang.String getHubArn() {
            return this.hubArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("hubArn", om.valueToTree(this.getHubArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_securityhub.HubReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HubReference.Jsii$Proxy that = (HubReference.Jsii$Proxy) o;

            return this.hubArn.equals(that.hubArn);
        }

        @Override
        public final int hashCode() {
            int result = this.hubArn.hashCode();
            return result;
        }
    }
}
